@@ -6,7 +6,6 @@ AAVE_USDT = Pair("AAVE_USDT", price_precision=3, quantity_precision=4)
 ACA_BTC = Pair("ACA_BTC", price_precision=9, quantity_precision=2)
 ACA_USDT = Pair("ACA_USDT", price_precision=4, quantity_precision=2)
 ADA_BTC = Pair("ADA_BTC", price_precision=9, quantity_precision=0)
-ADA_CRO = Pair("ADA_CRO", price_precision=3, quantity_precision=2)
 ADA_USDC = Pair("ADA_USDC", price_precision=5, quantity_precision=1)
 ADA_USDT = Pair("ADA_USDT", price_precision=5, quantity_precision=1)
 AERGO_BTC = Pair("AERGO_BTC", price_precision=10, quantity_precision=1)
@@ -31,6 +30,7 @@ API3_USDC = Pair("API3_USDC", price_precision=4, quantity_precision=2)
 API3_USDT = Pair("API3_USDT", price_precision=4, quantity_precision=2)
 ARPA_USDC = Pair("ARPA_USDC", price_precision=5, quantity_precision=1)
 AR_USDC = Pair("AR_USDC", price_precision=3, quantity_precision=3)
+AR_USDT = Pair("AR_USDT", price_precision=3, quantity_precision=3)
 ATOM_BTC = Pair("ATOM_BTC", price_precision=7, quantity_precision=2)
 ATOM_CRO = Pair("ATOM_CRO", price_precision=2, quantity_precision=2)
 ATOM_USDC = Pair("ATOM_USDC", price_precision=3, quantity_precision=3)
@@ -57,6 +57,7 @@ BICO_USDT = Pair("BICO_USDT", price_precision=4, quantity_precision=2)
 BIFI_USDT = Pair("BIFI_USDT", price_precision=2, quantity_precision=5)
 BNT_USDT = Pair("BNT_USDT", price_precision=4, quantity_precision=3)
 BOND_USDC = Pair("BOND_USDC", price_precision=3, quantity_precision=3)
+BOND_USDT = Pair("BOND_USDT", price_precision=3, quantity_precision=3)
 BOSON_USDT = Pair("BOSON_USDT", price_precision=4, quantity_precision=2)
 BRZ_USDT = Pair("BRZ_USDT", price_precision=5, quantity_precision=1)
 BTC_USDC = Pair("BTC_USDC", price_precision=2, quantity_precision=6)
@@ -101,7 +102,6 @@ DOGE_BTC = Pair("DOGE_BTC", price_precision=10, quantity_precision=1)
 DOGE_USDC = Pair("DOGE_USDC", price_precision=5, quantity_precision=1)
 DOGE_USDT = Pair("DOGE_USDT", price_precision=5, quantity_precision=2)
 DOT_BTC = Pair("DOT_BTC", price_precision=7, quantity_precision=4)
-DOT_CRO = Pair("DOT_CRO", price_precision=3, quantity_precision=3)
 DOT_USDC = Pair("DOT_USDC", price_precision=3, quantity_precision=3)
 DOT_USDT = Pair("DOT_USDT", price_precision=4, quantity_precision=3)
 DYDX_BTC = Pair("DYDX_BTC", price_precision=8, quantity_precision=3)
@@ -114,7 +114,6 @@ EGLD_USDT = Pair("EGLD_USDT", price_precision=4, quantity_precision=3)
 ELON_USDC = Pair("ELON_USDC", price_precision=10, quantity_precision=0)
 ELON_USDT = Pair("ELON_USDT", price_precision=10, quantity_precision=0)
 ENJ_BTC = Pair("ENJ_BTC", price_precision=9, quantity_precision=2)
-ENJ_CRO = Pair("ENJ_CRO", price_precision=3, quantity_precision=2)
 ENJ_USDC = Pair("ENJ_USDC", price_precision=4, quantity_precision=2)
 ENJ_USDT = Pair("ENJ_USDT", price_precision=5, quantity_precision=1)
 ENS_BTC = Pair("ENS_BTC", price_precision=8, quantity_precision=3)
@@ -155,7 +154,6 @@ GLMR_USDT = Pair("GLMR_USDT", price_precision=4, quantity_precision=2)
 GLM_USDT = Pair("GLM_USDT", price_precision=5, quantity_precision=1)
 GODS_USDT = Pair("GODS_USDT", price_precision=4, quantity_precision=2)
 GRT_BTC = Pair("GRT_BTC", price_precision=10, quantity_precision=1)
-GRT_CRO = Pair("GRT_CRO", price_precision=3, quantity_precision=2)
 GRT_USDT = Pair("GRT_USDT", price_precision=5, quantity_precision=2)
 GTC_USDT = Pair("GTC_USDT", price_precision=3, quantity_precision=3)
 HBAR_BTC = Pair("HBAR_BTC", price_precision=10, quantity_precision=1)
@@ -328,7 +326,6 @@ UNI_USDC = Pair("UNI_USDC", price_precision=3, quantity_precision=3)
 UNI_USDT = Pair("UNI_USDT", price_precision=4, quantity_precision=4)
 USDC_USDT = Pair("USDC_USDT", price_precision=4, quantity_precision=2)
 VET_BTC = Pair("VET_BTC", price_precision=10, quantity_precision=0)
-VET_CRO = Pair("VET_CRO", price_precision=4, quantity_precision=0)
 VET_USDC = Pair("VET_USDC", price_precision=6, quantity_precision=0)
 VET_USDT = Pair("VET_USDT", price_precision=6, quantity_precision=0)
 VOXEL_USDT = Pair("VOXEL_USDT", price_precision=4, quantity_precision=2)
